Learn R Programming

GLDreg (version 1.1.2)

Fitting functions for GLD regression : This is a collection of functions designed to implement the fitting algorithms for GLD regression in this package.

Description

These functions are for maintainers only and it is not designed for the users of this package.

Arguments

Value

List of computation results for various fitting algorithms, not intended to be used by users of this package

Author

Steve Su