The function is an extension of GLD.lm.surv and defaults to
1000 simulation runs, coefficients and statistical properties of coefficients
can be plotted as part of the output.
GLD.lm.full.surv(formula, censoring, data, param, maxit = 20000, fun,
method = "Nelder-Mead", range = c(0.01, 0.99), n.simu = 1000,
summary.plot = FALSE, init = NULL, alpha = 0.05, censor.type = "right",
adj.int = FALSE, GLD.adj = FALSE, adj.censor = TRUE, keep.uncen = TRUE)
Short description of estimation method used and whether the result converged
Bias correction used to ensure the line has zero mean residuals
A set of estimate coefficients from GLD regression
Predicted response value from model
Residual of model
Formula used in the model
Specify whether RS/FKML/FMKL GLD was used
The response variable
The explanatory variable(s)
GLD fitting function used in the computation process, outputted for internal programming use
Censoring data
AIC results
BIC results
Result of GLD fit, including censoring
Result of simulation for all coefficeints in the model
Result of GLD fit, including censoring
Bias corrected simulation results
A symbolic expression of the model to be fitted, similar to the formula
argument in lm, see formula for more information
1=Event, 0= Censored
Dataset containing variables of the model
Can be "rs", "fmkl" or "fkml"
Maximum number of iterations for numerical optimisation
If param="fmkl" or "fkml", this can be one of fun.RMFMKL.ml.m,
fun.RMFMKL.ml, for maximum
likelihood estimation (*.ml.m is a faster implementation of *.ml).
If param="rs", this can be one of fun.RPRS.ml.m,
fun.RPRS.ml, for maximum
likelihood estimation (*.ml.m is a faster implementation of *.ml).
Defaults to "Nelder-Mead" algorithm, can also be "SANN" but this is a lot slower and may not as good
The is the quantile range to plot the QQ plot, defaults to 0.01 and 0.99 to avoid potential problems with extreme values of GLD which might be -Inf or Inf.
Number of simulations, defaults to 1000.
If TRUE present graphical display of model fitted.
Initial values to start optimization process.
Significant level of goodness of fit test.
Can be " right" of "left censored.
Adjust intercept in final output?
Adjust GLD fitted to have theoretical zero mean?
Adjust censoring?
Keep uncensored values?
Steve Su
Su (2021) "Flexible Parametric Accelerated Failure Time Model" Journal of Biopharmaceutical Statistics Volume 31, 2021 - Issue 5
GLD.lm.full, GLD.quantreg, GLD.lm,
GLD.lm.surv
if (FALSE) {
actg.rs<-GLD.lm.full.surv(log(time)~factor(txgrp)+hemophil+cd4+priorzdv+age,
censoring=actg[which(actg$txgrp!=3 & actg$txgrp!=4),]$censor,
data=actg[which(actg$txgrp!=3 & actg$txgrp!=4),],
param="rs",fun=fun.RPRS.ml.m,summary.plot=F,n.simu=1000)
}Run the code above in your browser using DataLab