- formula
A symbolic expression of the model to be fitted, similar to the formula
argument in lm, see formula for more information
- censoring
1=Event, 0= Censored
- data
Dataset containing variables of the model
- param
Can be "rs", "fmkl" or "fkml"
- maxit
Maximum number of iterations for numerical optimisation
- fun
If param="fmkl" or "fkml", this can be one of fun.RMFMKL.ml.m,
fun.RMFMKL.ml, for maximum
likelihood estimation (*.ml.m is a faster implementation of *.ml).
If param="rs", this can be one of fun.RPRS.ml.m,
fun.RPRS.ml, for maximum
likelihood estimation (*.ml.m is a faster implementation of *.ml).
- method
Defaults to "Nelder-Mead" algorithm, can also be "SANN" but this is a lot slower
and may not as good
- diagnostics
Defaults to TRUE, which computes Kolmogorov-Smirnoff test, Kolmogorov-Smirnoff
Resample test, Data drive smooth test and do QQ plot on non censored data.
- range
The is the quantile range to plot the QQ plot, defaults to 0.01 and 0.99 to
avoid potential problems with extreme values of GLD which might be -Inf or Inf.
- init
Choose a different set of initial values to start the optimisation process. This
can either be full set of parameters including GLD parameter estimates, or it
can just be the coefficient estimates of the regression model.
- alpha
Significant level of goodness of fit test.
- censor.type
Can be" right" of "left censored.
- adj.int
Adjust intercept in final output?
- GLD.adj
Adjust GLD fitted to have theoretical zero mean?
- adj.censor
Adjust censoring?
- keep.uncen
Keep uncensored values?